@@ -77,9 +77,7 @@ function network(Graph){
   });
   
   options.colorScalenodeColor = "RdBkGn"; // default linear scale for nodes
-  options.colorScalelinkColor = "RdBkGn"; // default linear scale for links
-
-  options.adjustSymbols = true;
+  options.colorScalelinkColor = "RdBkGn"; // default linear scale for linkss
 
   options.charge = function(size){ return -(size/2); }
   options.linkDistance = function(size){ return size/20; };
@@ -755,21 +753,6 @@ function drawSVG(sel){
   var defs = svg.append("defs");
   d3.keys(colorScales).forEach(function(d){ addGradient(defs,d,colorScales[d]); });
 
-  defs.selectAll("marker")
-    .data(["end"])
-  .enter().append("marker")
-    .attr("id", String)
-    .attr("viewBox", "0 -5 10 10")
-    .attr("markerUnits", "userSpaceOnUse")
-    .attr("refX", 9)
-    .attr("refY", 0)
-    .attr("markerWidth", 8)
-    .attr("markerHeight", 8)
-    .attr("orient", "auto")
-  .append("path")
-    .attr("d", "M0,-3L10,0L0,3")
-    .style({"fill":defaultLinkColor});
-
   defs.append("clipPath")
     .attr("id","heatmapClip")
     .append("rect")
@@ -1030,7 +1013,7 @@ function drawNet(){
     if(options.nodeShape){
       var symbolList = d3.scale.ordinal()
          .range(symbolTypes)
-         .domain(d3.map(options.adjustSymbols? Graph.nodes : nodes, function(d) { return d[options.nodeShape]; }).keys());
+         .domain(d3.map(Graph.nodes, function(d) { return d[options.nodeShape]; }).keys());
 
       getShape = function(d) { return symbolList(d[options.nodeShape]); }
     }
@@ -1147,7 +1130,7 @@ function drawNet(){
   }
 
   function appendText(sel,row){
-    if(options.showLabels){
+    if(options.nodeLabel){
     sel.append("text")
       .attr("class","label")
       .attr("x", row? (heatmapTriangle? side + 6 : -6) : ((heatmapTriangle?-1:1) * (options.nodeOrder?18:6)))
@@ -1157,7 +1140,7 @@ function drawNet(){
       .attr("dy", ".32em")
       .style("fill",colorNodesScale? function(d, i) { return colorNodesScale(nodes[i][options.nodeColor]); } : null)
       .style("opacity",0)
-      .text(function(d, i) { return (!row && options.nodeLabel?nodes[i][options.nodeLabel]:nodes[i][options.nodeName]); })
+      .text(function(d, i) { return (!row ? nodes[i][options.nodeLabel] : nodes[i][options.nodeName]); })
       .on("click",function(d,i){
         var name = nodes[i][options.nodeName];
         nodes.forEach(function(p){
@@ -1328,7 +1311,7 @@ function drawNet(){
 
   // labels
   var label = svg.selectAll(".label")
-      .data(options.showLabels?nodes:[], function(d) { return d[options.nodeName]; });
+      .data(options.nodeLabel ? nodes : [], function(d) { return d[options.nodeName]; });
 
   label.exit().remove();
 
@@ -1345,7 +1328,7 @@ function drawNet(){
 
   label.selectAll("text")
     .attr("x", function(d) { return 10+(d.nodeSize-1)*4; })
-    .text(function(d) { return options.nodeLabel?d[options.nodeLabel]:d[options.nodeName]; });
+    .text(function(d) { return d[options.nodeLabel]; });
 
   labelEnter.transition()
       .duration(500)
@@ -1416,9 +1399,15 @@ function drawNet(){
 
   node.selectAll(".node > *").attr("transform", function(d) { return "scale("+d.nodeSize+")"; });
 
+  var linkId = function(d){
+    return "link_"+d3.range(0,d.Source.length).map(function(i){ return d.Source.charCodeAt(i); }).join("") + "_" + 
+           d3.range(0,d.Target.length).map(function(i){ return d.Target.charCodeAt(i); }).join("") +
+           (d.linkNum ? "_" + d.linkNum : "");
+  };
+
   // links
   var link = svg.selectAll(".link")
-        .data(links, function(d) { return d.Source + "_" + d.Target + (d.linkNum ? "_" + d.linkNum : ""); });
+        .data(links, linkId);
 
   link.exit().remove();
 
@@ -1427,11 +1416,44 @@ function drawNet(){
 
   link.attr("stroke-width", getLinkWidth)
       .attr("stroke", colorLinks)
-      .attr("marker-end", (options.showArrows)?"url(#end)":null);
+      .attr("marker-end", (options.showArrows) ? function(d){ return "url(#"+linkId(d)+")"; } : null);
+
+
+  // arrows
+  if(options.showArrows){
+    var marker = d3.select(".plot svg defs").selectAll("marker")
+    .data(links, linkId);
+
+    marker.exit().remove();
+
+    marker.enter().append("marker")
+      .attr("id", linkId)
+      .attr("markerUnits", "userSpaceOnUse")
+      .attr("refX", 10)
+      .attr("refY", 0)
+      .attr("markerWidth", 8)
+      .attr("orient", "auto")
+      .append("path")
+
+    var log2lwidth = function(d){ return Math.log(getLinkWidth(d)+1)/Math.log(2); }
+
+    marker.attr("viewBox",function(d){
+        var w = log2lwidth(d);
+        return "0 "+(-3*w)+" 10 "+(6*w);
+      })
+      .attr("markerHeight", function(d){ return 8*log2lwidth(d); })
+      .style("fill",colorLinks);
+
+    marker.select("path") 
+      .attr("d",function(d){
+        var w = log2lwidth(d);
+        return "M0,"+(-3*w)+"L10,"+(-0.5*w)+"L10,"+(0.5*w)+"L0,"+(3*w);
+      })
+  }
 
   // link text
   var linkText = svg.selectAll(".linkText")
-        .data(options.linkText?links:[], function(d) { return d.Source + "_" + d.Target + (d.linkNum ? "_" + d.linkNum : ""); })
+        .data(options.linkText?links:[], linkId)
 
   linkText.exit().remove();
 
@@ -1480,18 +1502,12 @@ function drawNet(){
   }
 
   if(options.nodeColor && !options.colorScalenodeColor){
-    if(options.adjustSymbols)
-        dat = d3.map(nodes.filter(function(d){ return d[options.nodeColor]!==null; }), function(d){ return d[options.nodeColor]; }).keys();
-    else
-        dat = colorNodesScale.domain();
+    dat = d3.map(nodes.filter(function(d){ return d[options.nodeColor]!==null; }), function(d){ return d[options.nodeColor]; }).keys();
     displayLegend(gScale,options.nodeColor,colorNodesScale,"circle",dat.sort(sortAsc));
   }
 
   if(options.nodeShape){
-    if(options.adjustSymbols)
-      dat = d3.map(nodes, function(d){ return d[options.nodeShape]; }).keys();
-    else
-      dat = symbolList.domain();
+    dat = d3.map(nodes, function(d){ return d[options.nodeShape]; }).keys();
     displayLegend(gScale,options.nodeShape,"#000000",symbolList,dat.sort(sortAsc));
   }
 
@@ -1547,8 +1563,9 @@ function tick() {
       }
 
       if(options.showArrows){
-        var offsetX = (dx * (d.target.nodeSize*4.514)) / dr,
-            offsetY = (dy * (d.target.nodeSize*4.514)) / dr;
+        var radius = (d.target.nodeSize*4.514),
+            offsetX = (dx * radius) / dr,
+            offsetY = (dy * radius) / dr;
 
         tx = tx - offsetX;
         ty = ty - offsetY;
@@ -1578,8 +1595,19 @@ function tick() {
         return "M" + d.source.x + "," + d.source.y + "L" + tx + "," + ty;
     });
 
-    d3.selectAll(".linkText").attr("x", function(d) { return ((d.target.x)+(d.source.x))/2; })
-        .attr("y", function(d) { return ((d.target.y)+(d.source.y))/2; });
+    d3.selectAll(".linkText").each(function(d){
+      if(d.linkNum && d.linkNum%2==0)
+        d3.select(this).attr("text-anchor", "end")
+
+      if(d.linkNum){
+        d3.select(this).attr("dy",(Math.floor(d.linkNum/2)%2==0? -1 : 1) * ((6*Math.ceil(d.linkNum/2))-3))
+        d3.select(this).attr("dx",(d.linkNum%2==0? -1 : 1) * (Math.ceil(d.linkNum/2)*6))
+      }
+
+      d3.select(this)
+        .attr("x", ((d.target.x)+(d.source.x))/2)
+        .attr("y", ((d.target.y)+(d.source.y))/2);
+    })
 
     d3.selectAll(".node, .net > .label").attr("transform", function(d){  return "translate(" + d.x + "," + d.y + ")"; });
 
@@ -1649,7 +1677,7 @@ function forceEnd(){
 
 function setColorScale(item,itemAttr){
     if(options[itemAttr]){
-      var data = options.adjustSymbols && !(item=='nodes' && options[itemAttr]=='weight') ? Graph[item] : force[item](),
+      var data = !(item=='nodes' && options[itemAttr]=='weight') ? Graph[item] : force[item](),
           scale;
       if(options["colorScale"+itemAttr] && dataType(data,options[itemAttr]) == "number"){
         var colorDomain = d3.extent(data.filter(function(d){ return d !== null; }), function(d) { return d[options[itemAttr]]; }),
@@ -1677,7 +1705,7 @@ function setColorScale(item,itemAttr){
 
 function getNumAttr(item,itemAttr,range,def){
     if(options[itemAttr]){
-      var data = options.adjustSymbols && !(item=='nodes' && options[itemAttr]=='weight') ? Graph[item] : force[item]();
+      var data = !(item=='nodes' && options[itemAttr]=='weight') ? Graph[item] : force[item]();
       if(data.length){
         if(dataType(data,options[itemAttr]) == "number"){
           var attrDomain = d3.extent(data, function(d) { return options.linkBipolar? Math.abs(d[options[itemAttr]]) : +d[options[itemAttr]]; });
@@ -1775,9 +1803,6 @@ function loadSVGbuttons(){
   var buttons = d3.select(".plot svg g.buttons"),
       dat = [],
       datStopResume = {txt: texts.stopresume, callback: stopResumeNet},
-      datAdjust = {txt: texts.adjustsymbols, callback: function(){
-        options.adjustSymbols = !options.adjustSymbols;
-      }, pressed: options.adjustSymbols},
       datSidebar = {txt: texts.showhidesidebar, callback: function(){
         options.showSidebar = !options.showSidebar;
         displaySidebar();
@@ -1799,15 +1824,6 @@ function loadSVGbuttons(){
         options.showImages = !options.showImages;
         drawNet();
       }},
-      datLabels = {txt: texts.showhidelabels, callback: function(){
-        options.showLabels = !options.showLabels;
-        if(!options.showLabels){
-          d3.selectAll(".label").transition()
-          .duration(500)
-          .style("opacity", 0)
-          .each("end", function(d,i){ if(!i) drawNet(); })
-        }else drawNet();
-      }},
       datMode = {txt: texts.netheatmap, callback: function(){
         heatmap = !heatmap;
         if(heatmap){
@@ -1834,13 +1850,11 @@ function loadSVGbuttons(){
   else
     dat = [datStopResume];
 
-  dat.push(datAdjust);
   dat.push(datSidebar);
   dat.push(datDirectional);
   dat.push(datLegend);
   if(!heatmap) dat.push(datAxes);
   if(options.nodeItem) dat.push(datImages);
-  dat.push(datLabels);
 
   if(Array.isArray(options.mode))
     dat.push(datMode);
@@ -1865,13 +1879,8 @@ function loadSVGbuttons(){
     .attr("ry",2)
     .attr("width",30)
     .attr("height",10)
-    .style("fill",d.pressed?"#666":null)
     .on("click",function(){
       d.callback();
-      if(typeof d.pressed != 'undefined'){
-        d3.select(this).style("fill",d.pressed?null:"#666");
-        d.pressed = !d.pressed;
-      }
     });
 
   d3.select(this).append("text")
@@ -2077,7 +2086,7 @@ function displayLegend(scale, txt, color, shape, dat){
            d.selected = false;
            if(!d.noShow){
              selecteds.each(function(p){
-               if((p=="null" && d[this.selected]===null) || (d[this.selected] && (d[this.selected]==p || (typeof d[this.selected] == 'object' && d[this.selected].indexOf(p)!=-1))))
+               if((p=="null" && d[this.selected]===null) || (p=="0" && d[this.selected]===0) || (d[this.selected] && (d[this.selected]==p || (typeof d[this.selected] == 'object' && d[this.selected].indexOf(p)!=-1))))
                  d.selected = true;
              });
            }
